@@ -3,6 +3,10 @@ import warnings
 from pathlib import Path
 from typing import Type, TypeVar, List, Optional, Tuple, Dict
 
+from openpyxl.styles import Font, Alignment
+from openpyxl.utils import get_column_letter
+from openpyxl.utils.dataframe import dataframe_to_rows
+from openpyxl.workbook import Workbook
 from pydantic import ValidationError, BaseModel
 import pandas as pd
 from openpyxl.reader.excel import load_workbook
@@ -21,7 +25,8 @@ def get_files_in_directory(directory: Path, file_name='*', force_presence=False)
         f for f in directory.glob(f"**/{file_name}.csv")
     ]
     if force_presence and len(file_obj) == 0:
-        logger.error(f'Failed to find files matching the {directory}/{file_name} pattern and presence is required. Exiting...')
+        logger.error(
+            f'Failed to find files matching the {directory}/{file_name} pattern and presence is required. Exiting...')
         exit(1)
     return file_obj
 
@@ -59,7 +64,7 @@ def load_csv_data(model_type: Type[T], data_files: List[Path]) -> None:
         f
         for f in data_files
         if f.name.endswith(".csv")
-        and len(set(cols).difference(set(get_csv_columns(f)))) == 0
+           and len(set(cols).difference(set(get_csv_columns(f)))) == 0
     ]
 
     data: List[model_type] = []
@@ -74,10 +79,11 @@ def load_csv_data(model_type: Type[T], data_files: List[Path]) -> None:
 
 
 def load_excel_data(
-    model_type: Type[T],
-    data_files: List[Path],
-    header_ndx: int = 0,
-    col_range: Optional[str] = None,
+        model_type: Type[T],
+        data_files: List[Path],
+        header_ndx: int = 0,
+        sheet_name: str | int = 0,
+        col_range: Optional[str] = None,
 ) -> None:
     fields = model_type.model_fields.keys()
     cols = [
@@ -92,10 +98,10 @@ def load_excel_data(
         f
         for f in data_files
         if f.name.endswith(".xlsx")
-        and len(
+           and len(
             set(cols).difference(set(get_excel_columns(f, header_ndx + 1, col_range)))
         )
-        == 0
+           == 0
     ]
 
     data: List[model_type] = []
@@ -106,7 +112,7 @@ def load_excel_data(
         )
 
     for file in filtered_files:
-        df = __read_excel(file, cols, header_ndx)
+        df = __read_excel(file=file, cols=cols, header_ndx=header_ndx, sheet_name=sheet_name)
         data.extend(__convert_to_models(file.name, df, model_type))
 
     with session_context() as session:
@@ -116,7 +122,7 @@ def load_excel_data(
 
 
 def __convert_to_models(
-    filename: str, df: pd.DataFrame, model_type: Type[T]
+        filename: str, df: pd.DataFrame, model_type: Type[T]
 ) -> List[T]:
     data: List[model_type] = []
     try:
@@ -130,10 +136,10 @@ def __convert_to_models(
 
 
 def load_raw_csv_data(
-    filename: Path,
-    table_name: str,
-    data_type_map: Optional[Dict[str, Type]] = None,
-    engine: Optional[Engine] = None,
+        filename: Path,
+        table_name: str,
+        data_type_map: Optional[Dict[str, Type]] = None,
+        engine: Optional[Engine] = None,
 ) -> None:
     df = __read_csv(filename, data_type_map=data_type_map)
 
@@ -151,13 +157,14 @@ def load_raw_csv_data(
 
 
 def load_raw_excel_data(
-    filename: Path,
-    table_name: str,
-    header_ndx: int = 0,
-    data_type_map: Optional[Dict[str, Type]] = None,
-    engine: Optional[Engine] = None,
+        filename: Path,
+        table_name: str,
+        header_ndx: int = 0,
+        sheet_name: str | int = 0,
+        data_type_map: Optional[Dict[str, Type]] = None,
+        engine: Optional[Engine] = None,
 ) -> None:
-    df = __read_excel(filename, header_ndx=header_ndx, data_type_map=data_type_map)
+    df = __read_excel(filename, header_ndx=header_ndx, data_type_map=data_type_map, sheet_name=sheet_name)
 
     if df is None:
         return
@@ -202,7 +209,8 @@ def convert_table_to_csv(InputTable: type[BaseModel], file: Path):
     df.to_csv(file, index=False)
 
 
-def export_to_sheet(InputTable: type[BaseModel], wb: Workbook, sheet_name: str, table_name: str = None, hide_sheet=False):
+def export_to_sheet(InputTable: type[BaseModel], wb: Workbook, sheet_name: str, table_name: str = None,
+                    hide_sheet=False):
     df = convert_table_to_df(InputTable)
     ws = wb.create_sheet(title=sheet_name)
     if hide_sheet:
@@ -242,9 +250,9 @@ def export_to_sheet(InputTable: type[BaseModel], wb: Workbook, sheet_name: str,
 
 
 def __read_csv(
-    file: Path | str,
-    cols: Optional[List[str]] = None,
-    data_type_map: Optional[Dict[str, Type]] = None,
+        file: Path | str,
+        cols: Optional[List[str]] = None,
+        data_type_map: Optional[Dict[str, Type]] = None,
 ) -> pd.DataFrame:
     return pd.read_csv(
         file, engine="pyarrow", usecols=cols, na_filter=False, dtype=data_type_map
@@ -252,14 +260,16 @@ def __read_csv(
 
 
 def __read_excel(
-    file: Path | str,
-    cols: Optional[List[str]] = None,
-    header_ndx: int = 0,
-    data_type_map: Optional[Dict[str, Type]] = None,
+        file: Path | str,
+        sheet_name: str | int = 0,
+        cols: Optional[List[str]] = None,
+        header_ndx: int = 0,
+        data_type_map: Optional[Dict[str, Type]] = None,
 ) -> pd.DataFrame:
     return pd.read_excel(
         io=file,
         usecols=cols,
+        sheet_name=sheet_name,
         na_filter=False,
         header=header_ndx,
         engine="calamine",
@@ -268,10 +278,10 @@ def __read_excel(
 
 
 def convert_to_csv(
-    data: List[BaseModel],
-    col_mapping_tuple: Tuple[List[str], Dict[str, str], List[str]],
-    filename: Path,
-    index=False,
+        data: List[BaseModel],
+        col_mapping_tuple: Tuple[List[str], Dict[str, str], List[str]],
+        filename: Path,
+        index=False,
 ) -> None:
     include_set, col_mapping, cols = col_mapping_tuple
     dict_data = [
@@ -282,4 +292,4 @@ def convert_to_csv(
     df = pd.DataFrame(dict_data)
 
     # Export DataFrame to CSV
-    df.to_csv(filename, index=index, columns=cols)
\ No newline at end of file
+    df.to_csv(filename, index=index, columns=cols)
